Index: adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseUpdaterTest.java |
diff --git a/adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseFilterEngineTest.java b/adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseUpdaterTest.java |
similarity index 54% |
copy from adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseFilterEngineTest.java |
copy to adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseUpdaterTest.java |
index 2741bb8e70b172460c52829e9609683b7e965a99..6096d8f0cd86250a6393bd6368c188adc5c95ce4 100644 |
--- a/adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseFilterEngineTest.java |
+++ b/adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseUpdaterTest.java |
@@ -17,40 +17,40 @@ |
package org.adblockplus.libadblockplus.tests; |
-import org.adblockplus.libadblockplus.FilterEngine; |
+import org.adblockplus.libadblockplus.Updater; |
import org.adblockplus.libadblockplus.LazyWebRequest; |
import org.adblockplus.libadblockplus.WebRequest; |
-public abstract class BaseFilterEngineTest extends BasePlatformTest |
+public abstract class BaseUpdaterTest extends BasePlatformTest |
{ |
- protected FilterEngine filterEngine; |
+ protected Updater updater; |
- @Override |
- protected void setUp() throws Exception |
- { |
- super.setUp(); |
- filterEngine = platform.getFilterEngine(); |
- } |
+ @Override |
+ protected void setUp() throws Exception |
+ { |
+ super.setUp(); |
+ updater = platform.getUpdater(); |
+ } |
- @Override |
- protected void tearDown() throws Exception |
- { |
- disposeFilterEngine(); |
- super.tearDown(); |
- } |
+ @Override |
+ protected void tearDown() throws Exception |
+ { |
+ disposeUpdater(); |
+ super.tearDown(); |
+ } |
- protected void disposeFilterEngine() throws InterruptedException |
- { |
- if (filterEngine != null) |
+ protected void disposeUpdater() throws InterruptedException |
{ |
- Thread.sleep(200); // let FS finish its operations |
- filterEngine = null; |
+ if (updater != null) |
+ { |
+ Thread.sleep(200); // let Updater finish its operations |
+ updater = null; |
+ } |
} |
- } |
- @Override |
- protected WebRequest createWebRequest() |
- { |
- return new LazyWebRequest(); |
- } |
+ @Override |
+ protected WebRequest createWebRequest() |
+ { |
+ return new LazyWebRequest(); |
+ } |
} |